%
% This function draws a circle on the given axes using the given line style
% and color.
% 
% @param x The x coordinate of the circle's center.
%
% @param y The y coordinate of the circle's center.
%
% @param r The circle's radius.
%
% @param axesHandle Draw on this axes object.
%
% @param lineStyle The style of the line. This can be:
%                  a. '-' solid line 
%                  b. '--' dashed line
%                  c. ':' dotted line
%                  d. '-.' dash-dot line
%
% @param lineWidth The width of our line.
%
% @param lineColor [R, G, B,] triple denoting the color (e.g. [1, 1, 1] 
%                  denotes white, [0, 0, 0] denotes black).
%                    
% @author Ziv Yaniv (zivy@isis.georgetown.edu)
%
function drawCircle(x, y, r, axesHandle, lineStyle, lineColor, lineWidth)

         %the rectangle function draws in the current axes, so we need to
         %set the given axes as the current and then return to the
         %setup prior to invoking this function
 prevAxes = gca;
 axes(axesHandle); 
 
           %not too intuitive, but matlab can draw circles by drawing
           %rectangles with curvature set to [1,1]
  rectangle ('Position', [x-r, y-r, 2*r, 2*r], 'Curvature', [1, 1],...
             'LineStyle', lineStyle,... 
             'EdgeColor', lineColor,... 
             'LineWidth', lineWidth);           
  axes(prevAxes);