%
% This function saves the given figure in three formats, emf
% (enhanced windows metafile), eps (encapsulated postscript), and fig (matlab
% figure). The emf format is used for figures incorporated into powerpoint/word documents. 
% The eps format is platform independent and is used for displaying figures 
% in documents written in latex. The reason for this approach to saving data is that the 
% postscript display in word/powerpoint is horrible, so we save both
% formats. Finally, the figure is saved in matlab's fig format. The reason for
% this is that the default 3D camera position often doesn't give an optimal 
% visualization of the data. To fix this, the user opens the fig file positions 
% the camera and manually saves the emf and eps files without rerunning scripts.
%
% @param figureHandle Which figure to save.
%
% @param fileNamePrefix Prefix for the file name. Given the prefix 'xyz'
%                       this function will create the files 'xyz.emf',
%                       'xyz.eps', and 'xyz.fig'.
%
% @param varargin{1} Optional parameter, the file name suffix. Valid values are
%                    'eps', 'emf', 'fig'. If one of these suffixes is used
%                    then the function will save the figure in the
%                    corresponding format.
%
% @author Ziv Yaniv (zivy@isis.georgetown.edu)
%
function saveFigure(figureHandle, fileNamePrefix, varargin)

if nargin==3
  if strcmp(varargin{1},'eps')
    print(figureHandle, '-depsc', fileNamePrefix);
  elseif strcmp(varargin{1},'emf')
    print(figureHandle, '-dmeta', fileNamePrefix);
  elseif strcmp(varargin{1},'fig')
    hgsave(figureHandle, fileNamePrefix);
  end
else
  print(figureHandle, '-depsc', fileNamePrefix);
  print(figureHandle, '-dmeta', fileNamePrefix);  
  hgsave(figureHandle, fileNamePrefix);
end
